# Please note that pip requires special processing.  Pip is bootstrap
# from python and in order to allow pip to rebuild pip in an rpm
# environment, it is necessary to add a command line flag that handles
# the fact that pip is being installed in the buildroot directory and
# strips the prefix.
#
# This command line flag is added by the patch in this package.  To
# rebuild pip from a non-mageia pip, you will need to first build pip
# without building wheel to create a pip with the command line flag,
# and then use that pip to generate a new pip from sources.
#
# Since this is messy and prone to break the python build stack, it is
# a good idea to contact the dev list before making major changes.

%bcond_with bootstrap

%define pypi_name pip
%define python_wheelname %{pypi_name}-%{version}-py3-none-any.whl
%define python_wheeldir %{_datadir}/python-wheels

Name:           python-pip
Version:        21.1.3
Release:        %mkrel 1
Group:          Development/Python
Summary:        A tool for installing and managing Python packages
License:        MIT
URL:            https://pypi.python.org/pypi/pip
Source0:        https://github.com/pypa/pip/archive/%{version}/%{pypi_name}-%{version}.tar.gz

BuildArch:      noarch

# Prevent removing of the system packages installed under /usr/lib
# when pip install -U is executed.
# https://bugzilla.redhat.com/show_bug.cgi?id=1550368#c24
Patch3:         remove-existing-dist-only-if-path-conflicts.patch

# Use the system level root certificate instead of the one bundled in certifi
# https://bugzilla.redhat.com/show_bug.cgi?id=1655253
Patch4:         dummy-certifi.patch

# Don't warn the user about pip._internal.main() entrypoint
# In Fedora, we use that in ensurepip and users cannot do anything about it,
# this warning is juts moot. Also, the warning breaks CPython test suite.
Patch5:         nowarn-pip._internal.main.patch

# Don't warn the user about packaging's LegacyVersion being deprecated.
# (This also breaks Python's test suite when warnings are treated as errors.)
# Upstream issue: https://github.com/pypa/packaging/issues/368
Patch6:         no-version-warning.patch

Patch10:	python-urllib3-CVE-2021-33503.patch

# Downstream only patch
# Users might have local installations of pip from using
# `pip install --user --upgrade pip` on older/newer versions.
# If they do that and they run `pip` or  `pip3`, the one from /usr/bin is used.
# However that's the one from this RPM package and the import in there might
# fail (it tries to import from ~/.local, but older or newer pip is there with
# a bit different API).
# We add this patch as a dirty workaround to make /usr/bin/pip* work with
# both pip10+ (from this RPM) and older or newer (19.3+) pip (from whatever).
# A proper fix is to put ~/.local/bin in front of /usr/bin in the PATH,
# however others are against that and we cannot change it for existing
# installs/user homes anyway.
# https://bugzilla.redhat.com/show_bug.cgi?id=1569488
# https://bugzilla.redhat.com/show_bug.cgi?id=1571650
# https://bugzilla.redhat.com/show_bug.cgi?id=1767212
# WARNING: /usr/bin/pip* are entrypoints, this cannot be applied in %%prep!
# %%patch10 doesn't work outside of %%prep, so we add it as a source
# Note that since pip 20, old main() import paths are preserved for backwards
# compatibility: https://github.com/pypa/pip/issues/7498
# Meaning we don't need to update any of the older pips to support 20+
# We also don't need to update Pythons to use new import path in ensurepip
Source10:        pip-allow-different-versions.patch

%description
pip is a package management system used to install and manage software packages
written in Python. Many packages can be found in the Python Package Index
(PyPI). pip is a recursive acronym that can stand for either "Pip Installs
Packages" or "Pip Installs Python".

%package -n python3-pip
Summary:        A tool for installing and managing Python3 packages
Group:          Development/Python
BuildRequires:  python3-devel
BuildRequires:  python3-setuptools
%if %{without bootstrap}
BuildRequires:  python3-pip
BuildRequires:  python3-wheel
%else
Provides:       python%{python3_pkgversion}dist(pip) = %{version}
Provides:       python%{python3_version}dist(pip) = %{version}
%endif
%{?python_provide:%python_provide python3-%{pypi_name}}
Requires:       python3-setuptools
Requires:       ca-certificates
Obsoletes:      python2-pip < 19.1.1-2

%description -n python3-pip
pip is a package management system used to install and manage software packages
written in Python. Many packages can be found in the Python Package Index
(PyPI). pip is a recursive acronym that can stand for either "Pip Installs
Packages" or "Pip Installs Python".

%if %{without bootstrap}
%package wheel
Summary:        The pip wheel
Requires:       ca-certificates

%description wheel
A Python wheel of pip to use with venv.
%endif

%prep
%setup -q -n %{pypi_name}-%{version}

%autopatch -p1

# Remove bundled egg-info
rm -rf %{pypi_name}.egg-info

# this goes together with patch4
rm src/pip/_vendor/certifi/*.pem

# Do not use furo as HTML theme in docs
# furo is not available in Fedora
sed -i '/html_theme = "furo"/d' docs/html/conf.py

# tests expect wheels in here
ln -s %{python_wheeldir} tests/data/common_wheels

# Upstream uses a Python 2/3 compatibility library for csv with Python 3 semantics in tests
# We only target Python 3 and csv23 is not (yet) packaged
# As of 20.1b1, this workaround was sufficient to get around the missing dependency
sed -i -e 's/csv23/csv/g' tests/lib/wheel.py


%build
%if %{without bootstrap}
%py3_build_wheel
%else
%py3_build
%endif

%install
%if %{without bootstrap}
%py3_install_wheel %{python_wheelname}
%else
%py3_install
%endif

# before we ln -s anything, we apply Source10 patch to all pips:
for PIP in %{buildroot}%{_bindir}/pip*; do
  patch -p1 --no-backup-if-mismatch $PIP < %{SOURCE10}
done

ln -s ./pip%{python3_version} %{buildroot}%{_bindir}/pip-%{python3_version}
ln -s ./pip-%{python3_version} %{buildroot}%{_bindir}/pip-3

# Make sure the INSTALLER is not pip and remove RECORD
# %%pyproject macros do this for all packages
%if %{without bootstrap}
echo rpm > %{buildroot}%{python3_sitelib}/pip-%{version}.dist-info/INSTALLER
rm %{buildroot}%{python3_sitelib}/pip-%{version}.dist-info/RECORD
%endif

%if %{without bootstrap}
mkdir -p %{buildroot}%{python_wheeldir}
install -p dist/%{python_wheelname} -t %{buildroot}%{python_wheeldir}
%endif

%files -n python3-pip
%license LICENSE.txt
%doc README.rst docs
%{_bindir}/pip
%{_bindir}/pip3
%{_bindir}/pip-3
%{_bindir}/pip%{python3_version}
%{_bindir}/pip-%{python3_version}
%{python3_sitelib}/pip*

%if %{without bootstrap}
%files wheel
%license LICENSE.txt
# we own the dir for simplicity
%dir %{python_wheeldir}/
%{python_wheeldir}/%{python_wheelname}
%endif


%changelog
* Sun Jul 25 2021 wally <wally> 21.1.3-1.mga8
+ Revision: 1737737
- new version 21.1.3 (mga#29288)

* Fri Jul 23 2021 luigiwalser <luigiwalser> 20.3.3-3.3.mga8
+ Revision: 1737505
- add patch to fix CVE-2021-33503

* Fri Jul 23 2021 neoclust <neoclust> 20.3.3-3.2.mga8
+ Revision: 1737477
- Add P101: Fixing CVE-2021-28363 (mga#29010)

* Fri Jul 23 2021 neoclust <neoclust> 20.3.3-3.1.mga8
+ Revision: 1737472
- Add P100: Fixes CVE-2021-3572 (mga#29010)

* Tue Dec 22 2020 wally <wally> 20.3.3-3.mga8
+ Revision: 1662954
- sync patches and .spec with Fedora where appropriate

* Tue Dec 22 2020 wally <wally> 20.3.3-2.mga8
+ Revision: 1662913
- add a patch from upstream pull request to verify built wheel contains valid metadata

* Fri Dec 18 2020 wally <wally> 20.3.3-1.mga8
+ Revision: 1660905
- new version 20.3.3

* Mon Jul 20 2020 wally <wally> 20.1.1-1.mga8
+ Revision: 1607441
- new version 20.1.1
- sync with Fedora where appropriate

* Sun Jul 05 2020 joequant <joequant> 19.3.1-4.mga8
+ Revision: 1602284
- fix bootstrap

* Fri Feb 28 2020 wally <wally> 19.3.1-3.mga8
+ Revision: 1552019
- add patch from Fedora to make new pip to support the old private API of main()

* Wed Feb 19 2020 umeabot <umeabot> 19.3.1-2.mga8
+ Revision: 1544152
- Mageia 8 Mass Rebuild

* Fri Jan 24 2020 daviddavid <daviddavid> 19.3.1-1.mga8
+ Revision: 1482649
- new version: 19.3.1

* Wed Oct 02 2019 daviddavid <daviddavid> 19.2.3-1.mga8
+ Revision: 1448789
- new version: 19.2.3
- drop patch that should strip path prefixes from RECORD files, the paths are relative

* Tue Sep 03 2019 wally <wally> 19.1.1-3.mga8
+ Revision: 1436774
- non-bootstrap build for python3.8

* Tue Sep 03 2019 wally <wally> 19.1.1-2.mga8
+ Revision: 1436755
- bootstrap build for python3.8
- drop python2 support

* Sun Jul 07 2019 daviddavid <daviddavid> 19.1.1-1.mga8
+ Revision: 1419305
- new version: 19.1.1

* Tue Mar 05 2019 guillomovitch <guillomovitch> 19.0.3-1.mga7
+ Revision: 1371724
- new version 19.0.3

* Fri Jan 04 2019 wally <wally> 18.1-5.mga7
+ Revision: 1349231
- disable bootstrap

* Fri Jan 04 2019 wally <wally> 18.1-4.mga7
+ Revision: 1349202
- another bootstrap build for python3.7

* Fri Jan 04 2019 wally <wally> 18.1-3.mga7
+ Revision: 1349196
- disable bootstrap
- bootstrap build for python3.7

* Tue Jan 01 2019 wally <wally> 18.1-1.mga7
+ Revision: 1348163
- new version 18.1 (sync a bit with Fedora)
- create python-pip-wheel

* Tue Sep 25 2018 tv <tv> 9.0.3-5.mga7
+ Revision: 1304900
- rebuild with wheel

* Tue Sep 25 2018 tv <tv> 9.0.3-4.mga7
+ Revision: 1304876
- fix BR for bootstrapping: pythonXdist(*) -> pythonX-* + disable wheel again
- fix BR for bootstrapping: python3dist(setuptools) -> python3-setuptools
- fix BR for bootstrapping: python2dist(setuptools) -> python2-setuptools
- rebuild with wheel

* Mon Sep 24 2018 tv <tv> 9.0.3-3.mga7
+ Revision: 1303663
- rebuild w/o wheel

* Thu Sep 20 2018 umeabot <umeabot> 9.0.3-2.mga7
+ Revision: 1289670
- Mageia 7 Mass Rebuild

* Sat Mar 31 2018 kekepower <kekepower> 9.0.3-1.mga7
+ Revision: 1213726
- Update to version 9.0.3
- Renamed python-pip to python2-pip
- Use python_provide

* Sat Jul 29 2017 philippem <philippem> 9.0.1-2.mga7
+ Revision: 1132538
- try to force python-pkg-resources version
- fix typo missing %
- Rebuild for Python 3.6 with wheel

* Sat Jul 29 2017 philippem <philippem> 9.0.1-1.mga7
+ Revision: 1132498
- Remove setup.py test support and python_requires
- Remove setup.py test support (from upstream)
- Remove setup.py test support (from upstream)
- upgrade to 9.0.1, first step for Python 3.6.2
- revert to r929830, keep pip 8.0.2

* Sat May 27 2017 philippem <philippem> 8.0.3-1.mga6
+ Revision: 1105186
- update to 8.0.3
+ joequant <joequant>
- added comment

* Mon Feb 01 2016 joequant <joequant> 8.0.2-6.mga6
+ Revision: 929686
- rebuild for wheel

* Mon Feb 01 2016 joequant <joequant> 8.0.2-5.mga6
+ Revision: 929685
- bump in queue
- fix wheel breakage - bootstrap
+ philippem <philippem>
- enable wheel

* Thu Jan 28 2016 philippem <philippem> 8.0.2-2.mga6
+ Revision: 928459
- need to re bootstrap
- enable patch for wheel

* Sun Jan 24 2016 joequant <joequant> 8.0.2-1.mga6
+ Revision: 926779
- upgrade to 8.0.2

* Wed Oct 07 2015 tv <tv> 7.1.2-5.mga6
+ Revision: 886741
- rebuild for python 3.5

* Wed Oct 07 2015 joequant <joequant> 7.1.2-4.mga6
+ Revision: 886675
- upgrade to 3.5

* Wed Sep 23 2015 philippem <philippem> 7.1.2-3.mga6
+ Revision: 882298
- Rebuild as wheel for Python 3.5

* Tue Sep 22 2015 philippem <philippem> 7.1.2-2.mga6
+ Revision: 882272
- rebuild without wheel, first step for Python 3.5

* Sun Aug 30 2015 joequant <joequant> 7.1.2-1.mga6
+ Revision: 871364
- upgrade to 7.1.2

* Sat Aug 22 2015 joequant <joequant> 7.1.1-1.mga6
+ Revision: 868008
- upgrade to 7.1.1

* Sun Aug 02 2015 joequant <joequant> 7.1.0-1.mga6
+ Revision: 860857
- upgrade to 7.1.0

* Tue Apr 28 2015 philippem <philippem> 6.1.1-2.mga5
+ Revision: 820817
- update to 6.1.1 fix mga#15748

* Wed Jan 07 2015 philippem <philippem> 1.5.6-8.mga5
+ Revision: 809189
- fix CVE-2014-8991 mga#14969

* Wed Oct 15 2014 umeabot <umeabot> 1.5.6-7.mga5
+ Revision: 739105
- Second Mageia 5 Mass Rebuild

* Sat Sep 27 2014 tv <tv> 1.5.6-6.mga5
+ Revision: 729320
- rebuild for missing pythoneggs deps

* Tue Sep 16 2014 umeabot <umeabot> 1.5.6-5.mga5
+ Revision: 688216
- Mageia 5 Mass Rebuild

* Tue Jun 03 2014 philippem <philippem> 1.5.6-4.mga5
+ Revision: 632194
- add egg provides

* Sat May 31 2014 pterjan <pterjan> 1.5.6-3.mga5
+ Revision: 628885
- Rebuild for new Python

* Sat May 24 2014 philippem <philippem> 1.5.6-2.mga5
+ Revision: 625292
- Rebuild as wheel for Python 3.4

* Fri May 23 2014 philippem <philippem> 1.5.6-1.mga5
+ Revision: 625238
- update to 1.5.6, first step for Python 3.4

* Sun Apr 20 2014 philippem <philippem> 1.5.4-1.mga5
+ Revision: 617149
- update to 1.5.4

* Sun Dec 01 2013 philippem <philippem> 1.4.1-4.mga4
+ Revision: 554518
- change-match_hostname-to-follow-RFC-6125 (mga#11785)

* Tue Oct 22 2013 umeabot <umeabot> 1.4.1-3.mga4
+ Revision: 543939
- Mageia 4 Mass Rebuild

* Tue Oct 15 2013 pterjan <pterjan> 1.4.1-2.mga4
+ Revision: 499119
- Rebuild to add different pythonegg provides for python 2 and 3

* Mon Sep 23 2013 joequant <joequant> 1.4.1-1.mga4
+ Revision: 484288
- update to 1.4.1

* Fri Jul 26 2013 philippem <philippem> 1.3.1-3.mga4
+ Revision: 458721
- Fix for CVE 2013-2099
- Add Python 3

* Wed May 08 2013 neoclust <neoclust> 1.3.1-2.mga3
+ Revision: 412711
- fix proxy support
- New version ( fix CVE-2013-1888 ) mga #10007)

* Tue Mar 05 2013 neoclust <neoclust> 1.2.1-2.mga3
+ Revision: 401418
- Add missing deps ( mga #9246 )

* Mon Jan 28 2013 joequant <joequant> 1.2.1-1.mga3
+ Revision: 392901
- imported package python-pip

